@@ -1,22 +1,22 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import os
-
 import numpy as np
 import matplotlib.pyplot as plt
 
 import pywt
+import pywt.data
 
 
-ecg = np.load(os.path.join('data', 'ecg.npy'))
+ecg = pywt.data.ecg()
+
 data1 = np.concatenate((np.arange(1, 400),
                         np.arange(398, 600),
                         np.arange(601, 1024)))
 x = np.linspace(0.082, 2.128, num=1024)[::-1]
 data2 = np.sin(40 * np.log(x)) * np.sign((np.log(x)))
 
-mode = pywt.MODES.sp1DWT = 1
+mode = pywt.Modes.sp1DWT = 1
 
 
 def plot_coeffs(data, w, title, use_dwt=True):
